@@ -117,7 +117,7 @@ void emboss_getoptions(char *pgm, int argc, char *argv[])
   mulsets = false;
   datasets = 1;
 
-    embInitP (pgm, argc, argv, "PHYLIPNEW");
+  embInitPV (pgm, argc, argv, "PHYLIPNEW",VERSION);
 
     phylofreq = ajAcdGetFrequencies("infile");
 
@@ -1368,9 +1368,9 @@ void maketree()
   if ( jumb < njumble)
     return;
   if (progress) {
-    printf("\n\nOutput written to file \"%s\"\n\n", outfilename);
+    printf("\nOutput written to file \"%s\"\n", outfilename);
     if (trout)
-      printf("Tree also written onto file \"%s\"\n\n", outtreename);
+      printf("\nTree also written onto file \"%s\"\n\n", outtreename);
   }
   freeview(&curtree, nonodes2);
   if (!usertree) {
@@ -1424,7 +1424,7 @@ int main(int argc, Char *argv[])
   fixmacfile(outfilename);
   fixmacfile(outtreename);
 #endif
-  printf("Done.\n\n");
+  printf("\nDone.\n\n");
 #ifdef WIN32
   phyRestoreConsoleAttributes();
 #endif
