@@ -65,7 +65,7 @@ AjPFile embossouttree;
 
 Char infilename[FNMLNGTH], intreename[FNMLNGTH];
 long nonodes2, outgrno, nums, col, datasets, ith, njumble, jumb=0, numtrees;
-long inseed, nummatrices=0;
+long inseed;
 vector *x;
 intvector *reps;
 boolean minev, global, jumble, lengths, usertree, lower, upper, negallowed,
@@ -111,12 +111,12 @@ void   emboss_getoptions(char *pgm, int argc, char *argv[])
   mulsets = false;
   datasets = 1;
 
-    embInitP (pgm, argc, argv, "PHYLIPNEW");
+  embInitPV(pgm, argc, argv, "PHYLIPNEW",VERSION);
    
     phylodists = ajAcdGetDistances("datafile");
 
-    while (phylodists[nummatrices])
-    nummatrices++;
+    while (phylodists[datasets])
+    datasets++;
 
 
     minev = ajAcdGetBoolean("minev");
@@ -1020,10 +1020,9 @@ void maketree()
     }
   }
   if (jumb == njumble && progress) {
-    printf("\nOutput written to file \"%s\"\n\n", outfilename);
+    printf("\nOutput written to file \"%s\"\n", outfilename);
     if (trout) {
-      printf("Tree also written onto file \"%s\"\n", outtreename);
-      putchar('\n');
+      printf("\nTree also written onto file \"%s\"\n", outtreename);
     }
   }
 }  /* maketree */
@@ -1066,7 +1065,7 @@ int main(int argc, Char *argv[])
   fixmacfile(outfilename);
   fixmacfile(outtreename);
 #endif
-  printf("Done.\n\n");
+  printf("\nDone.\n\n");
 #ifdef WIN32
   phyRestoreConsoleAttributes();
 #endif
