@@ -601,7 +601,7 @@ void emboss_getoptions(char *pgm, int argc, char *argv[])
     phyloratecat = ajAcdGetProperties("categories");      
 
 
-    gammamethod = ajAcdGetListSingle("gamma");
+    gammamethod = ajAcdGetListSingle("gammatype");
 
     if(ajStrMatchC(gammamethod, "n")) {
       rrate      = (double *) Malloc(rcategs*sizeof(double));
