@@ -366,7 +366,7 @@ void   emboss_getoptions(char *pgm, int argc, char *argv[])
     outgrno = ajAcdGetInt("outgrno");
     if(outgrno != 0) outgropt = true;
     else outgrno = 1;
-    thresh = ajAcdGetToggle("thresh");
+    thresh = ajAcdGetToggle("dothreshold");
     if(thresh)  threshold = ajAcdGetFloat("threshold");
     
 
