@@ -393,7 +393,7 @@ void emboss_getoptions(char *pgm, int argc, char *argv[])
   nexus = false;
   xmltree = false;
 
-    embInitP (pgm, argc, argv, "PHYLIPNEW");
+  embInitPV(pgm, argc, argv, "PHYLIPNEW",VERSION);
 
       phylotrees = ajAcdGetTree("intreefile");
 
