@@ -197,7 +197,7 @@ void emboss_getoptions(char *pgm, int argc, char *argv[])
   factors = false;
   enzymes = false;
 
-    embInitP (pgm, argc, argv, "PHYLIPNEW");
+  embInitPV(pgm, argc, argv, "PHYLIPNEW",VERSION);
 
     seqset = ajAcdGetSeqset("infilesequences");
 
@@ -1452,16 +1452,16 @@ void writefactors(void)
 {
     long i, k, l, m, n, writesites;
   char symbol;
-  steptr wfactor;
+  /*steptr wfactor;*/
   long grp;
 
   if(!justwts || firstrep){
     if(justwts){
       writesites = sites;
-      wfactor = factorr;
+      /*wfactor = factorr;*/
     } else {
       writesites = newergroups;
-      wfactor = newerfactor;
+      /*wfactor = newerfactor;*/
     }
     symbol = '+';
     if (interleaved)
